@@ -27,7 +27,7 @@ from typing import Dict, Iterator, List, Optional, Tuple
 from ..analysis import get_lucene_analyzer, JAnalyzer, JAnalyzerUtils
 from ..pyclass import autoclass, JString
 from ..search import Document
-from pyserini.util import download_prebuilt_index, get_indexes_info
+from pyserini.util import download_prebuilt_index, get_sparse_indexes_info
 from pyserini.prebuilt_index_info import INDEX_INFO
 
 logger = logging.getLogger(__name__)
@@ -55,7 +55,7 @@ class JGenerators(Enum):
     AclAnthologyGenerator = autoclass('io.anserini.index.generator.AclAnthologyGenerator')
     DefaultLuceneDocumentGenerator = autoclass('io.anserini.index.generator.DefaultLuceneDocumentGenerator')
     TweetGenerator = autoclass('io.anserini.index.generator.TweetGenerator')
-    WapoGenerator = autoclass('io.anserini.index.generator.WashingtonPostGenerator')
+    WashingtonPostGenerator = autoclass('io.anserini.index.generator.WashingtonPostGenerator')
 
 
 class Generator:
@@ -154,7 +154,7 @@ class IndexReader:
 
     @classmethod
     def from_prebuilt_index(cls, prebuilt_index_name: str):
-        """Build an index reader from the prebuilt index, download the index if necessary.
+        """Build an index reader from a prebuilt index; download the index if necessary.
 
         Parameters
         ----------
@@ -166,7 +166,14 @@ class IndexReader:
         IndexReader
             Index reader built from the prebuilt index.
         """
-        index_dir = download_prebuilt_index(prebuilt_index_name)
+        print(f'Attempting to initialize pre-built index {prebuilt_index_name}.')
+        try:
+            index_dir = download_prebuilt_index(prebuilt_index_name)
+        except ValueError as e:
+            print(str(e))
+            return None
+
+        print(f'Initializing {prebuilt_index_name}...')
         return cls(index_dir)
 
     @classmethod
@@ -191,8 +198,8 @@ class IndexReader:
 
     @staticmethod
     def list_prebuilt_indexes():
-        """Display available prebuilt indexes' information."""
-        get_indexes_info()
+        """Display information about available prebuilt indexes."""
+        get_sparse_indexes_info()
 
     def analyze(self, text: str, analyzer=None) -> List[str]:
         """Analyze a piece of text. Applies Anserini's default Lucene analyzer if analyzer not specified.
