@@ -28,7 +28,9 @@ from jnius import autoclass, cast
 
 # Base Java classes
 JString = autoclass('java.lang.String')
+JFloat = autoclass('java.lang.Float')
 JPath = autoclass('java.nio.file.Path')
 JPaths = autoclass('java.nio.file.Paths')
 JList = autoclass('java.util.List')
 JArrayList = autoclass('java.util.ArrayList')
+JHashMap = autoclass('java.util.HashMap')
