@@ -14,10 +14,10 @@
 # limitations under the License.
 #
 
-from ._base import Document, JDocument, JQuery, get_topics, get_topics_with_reader
+from ._base import Document, JDocument, JQuery, JDisjunctionMaxQueryGenerator, get_topics, get_topics_with_reader, get_qrels_file, get_qrels
 from ._searcher import JSimpleSearcherResult, LuceneSimilarities, SimpleFusionSearcher, SimpleSearcher
 from ._nearest_neighbor import SimpleNearestNeighborSearcher, JSimpleNearestNeighborSearcherResult
 
 __all__ = ['Document', 'JDocument', 'JQuery', 'LuceneSimilarities', 'SimpleFusionSearcher', 'SimpleSearcher',
            'JSimpleSearcherResult', 'SimpleNearestNeighborSearcher', 'JSimpleNearestNeighborSearcherResult',
-           'get_topics', 'get_topics_with_reader']
+           'JDisjunctionMaxQueryGenerator', 'get_topics', 'get_topics_with_reader', 'get_qrels_file', 'get_qrels']
